﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Media;

namespace DependencyProperies
{
    public class BetterTextLabel : FrameworkElement
    {
        public static readonly DependencyProperty FontSizeProperty;
        public static readonly DependencyProperty TextProperty;

        public double FontSize
        {
            get { return (double)GetValue(FontSizeProperty); }
            set { SetValue(FontSizeProperty, value); }
        }

        public string Text
        {
            get { return (string)GetValue(TextProperty); }
            set { SetValue(TextProperty, value); }
        }

        /*
         * Statischer Konstruktor
         * Hier werden die Dependency-Properties in der Property Engine registriert.
         */
        static BetterTextLabel()
        {
            FontSizeProperty = DependencyProperty.Register(
                "FontSize"
                , typeof(double)
                , typeof(BetterTextLabel)
                , new FrameworkPropertyMetadata(
                    11.0 //Default Value
                    , FrameworkPropertyMetadataOptions.AffectsMeasure) //Beeinflusst Maße des Buttons
                , new ValidateValueCallback(FontSizeValidator));

            TextProperty = DependencyProperty.Register(
                "Text"
                , typeof(string)
                , typeof(BetterTextLabel)
                , new FrameworkPropertyMetadata(
                    "" //Default Value
                    , FrameworkPropertyMetadataOptions.AffectsMeasure));
        }

        private static bool FontSizeValidator(object value)
        {
            return (double)value > 0;
        }

        private FormattedText GetFormattedText()
        {
            return new FormattedText(
                this.Text
                , System.Globalization.CultureInfo.InvariantCulture
                , FlowDirection.LeftToRight
                , new Typeface("Arial")
                , this.FontSize
                , Brushes.Black);
        }

        protected override Size MeasureOverride(Size availableSize)
        {
            FormattedText txt = GetFormattedText();
            return new Size(txt.Width + 5, txt.Height + 5);
        }

        protected override void OnRender(DrawingContext drawingContext)
        {
            base.OnRender(drawingContext);
            drawingContext.DrawRectangle(Brushes.LightGray, null, new Rect(this.RenderSize));
            FormattedText txt = GetFormattedText();
            drawingContext.DrawText(txt, new Point(2.5, 2.5));
        }
    }
}
