﻿using System;
using System.Windows;
using System.Windows.Media;
using System.Globalization;


namespace DependencyProperies
{
  public class TextLabel:FrameworkElement
  {
    private double _FontSize = 11.0;
    private string _Text = string.Empty;

    public double FontSize
    {
        get { return _FontSize; }
        set
        { 
            if (value > 0)
                _FontSize = value;
        }
    }

    public string Text
    {
        get { return _Text; }
        set { _Text = value; }
    }

    private FormattedText GetFormattedText()
    {
        return
        new FormattedText("Label mit klassischer FontSize"
        , CultureInfo.InvariantCulture
        , FlowDirection.LeftToRight
        , new Typeface("Arial")
        , this.FontSize
        , Brushes.Black);
    }
    
    protected override Size MeasureOverride(Size availableSize)
    {
      FormattedText txt = GetFormattedText();
      return new Size(txt.Width+5, txt.Height+5);
    }

    protected override void OnRender(DrawingContext drawingContext)
    {
      base.OnRender(drawingContext);

      drawingContext.DrawRectangle(Brushes.LightGray
                                 , null
                                 , new Rect(this.RenderSize));

      FormattedText txt = GetFormattedText();

      drawingContext.DrawText(txt, new Point(2.5, 2.5));
    }
  }
}
